@@ -39,6 +39,12 @@ import pytz
 
 from google import api_core
 from google.cloud.bigquery import schema
+from google.cloud.bigquery._pandas_helpers import _BIGNUMERIC_SUPPORT
+
+
+skip_if_no_bignumeric = pytest.mark.skipif(
+    not _BIGNUMERIC_SUPPORT, reason="BIGNUMERIC support requires pyarrow>=3.0.0",
+)
 
 
 @pytest.fixture
@@ -70,6 +76,15 @@ def is_numeric(type_):
     )(type_)
 
 
+def is_bignumeric(type_):
+    # See: https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types#numeric-type
+    return all_(
+        pyarrow.types.is_decimal,
+        lambda type_: type_.precision == 76,
+        lambda type_: type_.scale == 38,
+    )(type_)
+
+
 def is_timestamp(type_):
     # See: https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types#timestamp-type
     return all_(
@@ -120,6 +135,9 @@ def test_all_():
         ("FLOAT", "NULLABLE", pyarrow.types.is_float64),
         ("FLOAT64", "NULLABLE", pyarrow.types.is_float64),
         ("NUMERIC", "NULLABLE", is_numeric),
+        pytest.param(
+            "BIGNUMERIC", "NULLABLE", is_bignumeric, marks=skip_if_no_bignumeric,
+        ),
         ("BOOLEAN", "NULLABLE", pyarrow.types.is_boolean),
         ("BOOL", "NULLABLE", pyarrow.types.is_boolean),
         ("TIMESTAMP", "NULLABLE", is_timestamp),
@@ -198,6 +216,12 @@ def test_all_():
             "REPEATED",
             all_(pyarrow.types.is_list, lambda type_: is_numeric(type_.value_type)),
         ),
+        pytest.param(
+            "BIGNUMERIC",
+            "REPEATED",
+            all_(pyarrow.types.is_list, lambda type_: is_bignumeric(type_.value_type)),
+            marks=skip_if_no_bignumeric,
+        ),
         (
             "BOOLEAN",
             "REPEATED",
@@ -270,34 +294,41 @@ def test_bq_to_arrow_data_type_w_struct(module_under_test, bq_type):
         schema.SchemaField("field05", "FLOAT"),
         schema.SchemaField("field06", "FLOAT64"),
         schema.SchemaField("field07", "NUMERIC"),
-        schema.SchemaField("field08", "BOOLEAN"),
-        schema.SchemaField("field09", "BOOL"),
-        schema.SchemaField("field10", "TIMESTAMP"),
-        schema.SchemaField("field11", "DATE"),
-        schema.SchemaField("field12", "TIME"),
-        schema.SchemaField("field13", "DATETIME"),
-        schema.SchemaField("field14", "GEOGRAPHY"),
+        schema.SchemaField("field09", "BOOLEAN"),
+        schema.SchemaField("field10", "BOOL"),
+        schema.SchemaField("field11", "TIMESTAMP"),
+        schema.SchemaField("field12", "DATE"),
+        schema.SchemaField("field13", "TIME"),
+        schema.SchemaField("field14", "DATETIME"),
+        schema.SchemaField("field15", "GEOGRAPHY"),
     )
+
+    if _BIGNUMERIC_SUPPORT:
+        fields += (schema.SchemaField("field08", "BIGNUMERIC"),)
+
     field = schema.SchemaField("ignored_name", bq_type, mode="NULLABLE", fields=fields)
     actual = module_under_test.bq_to_arrow_data_type(field)
-    expected = pyarrow.struct(
-        (
-            pyarrow.field("field01", pyarrow.string()),
-            pyarrow.field("field02", pyarrow.binary()),
-            pyarrow.field("field03", pyarrow.int64()),
-            pyarrow.field("field04", pyarrow.int64()),
-            pyarrow.field("field05", pyarrow.float64()),
-            pyarrow.field("field06", pyarrow.float64()),
-            pyarrow.field("field07", module_under_test.pyarrow_numeric()),
-            pyarrow.field("field08", pyarrow.bool_()),
-            pyarrow.field("field09", pyarrow.bool_()),
-            pyarrow.field("field10", module_under_test.pyarrow_timestamp()),
-            pyarrow.field("field11", pyarrow.date32()),
-            pyarrow.field("field12", module_under_test.pyarrow_time()),
-            pyarrow.field("field13", module_under_test.pyarrow_datetime()),
-            pyarrow.field("field14", pyarrow.string()),
-        )
+
+    expected = (
+        pyarrow.field("field01", pyarrow.string()),
+        pyarrow.field("field02", pyarrow.binary()),
+        pyarrow.field("field03", pyarrow.int64()),
+        pyarrow.field("field04", pyarrow.int64()),
+        pyarrow.field("field05", pyarrow.float64()),
+        pyarrow.field("field06", pyarrow.float64()),
+        pyarrow.field("field07", module_under_test.pyarrow_numeric()),
+        pyarrow.field("field09", pyarrow.bool_()),
+        pyarrow.field("field10", pyarrow.bool_()),
+        pyarrow.field("field11", module_under_test.pyarrow_timestamp()),
+        pyarrow.field("field12", pyarrow.date32()),
+        pyarrow.field("field13", module_under_test.pyarrow_time()),
+        pyarrow.field("field14", module_under_test.pyarrow_datetime()),
+        pyarrow.field("field15", pyarrow.string()),
     )
+    if _BIGNUMERIC_SUPPORT:
+        expected += (pyarrow.field("field08", module_under_test.pyarrow_bignumeric()),)
+    expected = pyarrow.struct(expected)
+
     assert pyarrow.types.is_struct(actual)
     assert actual.num_fields == len(fields)
     assert actual.equals(expected)
@@ -314,34 +345,41 @@ def test_bq_to_arrow_data_type_w_array_struct(module_under_test, bq_type):
         schema.SchemaField("field05", "FLOAT"),
         schema.SchemaField("field06", "FLOAT64"),
         schema.SchemaField("field07", "NUMERIC"),
-        schema.SchemaField("field08", "BOOLEAN"),
-        schema.SchemaField("field09", "BOOL"),
-        schema.SchemaField("field10", "TIMESTAMP"),
-        schema.SchemaField("field11", "DATE"),
-        schema.SchemaField("field12", "TIME"),
-        schema.SchemaField("field13", "DATETIME"),
-        schema.SchemaField("field14", "GEOGRAPHY"),
+        schema.SchemaField("field09", "BOOLEAN"),
+        schema.SchemaField("field10", "BOOL"),
+        schema.SchemaField("field11", "TIMESTAMP"),
+        schema.SchemaField("field12", "DATE"),
+        schema.SchemaField("field13", "TIME"),
+        schema.SchemaField("field14", "DATETIME"),
+        schema.SchemaField("field15", "GEOGRAPHY"),
     )
+
+    if _BIGNUMERIC_SUPPORT:
+        fields += (schema.SchemaField("field08", "BIGNUMERIC"),)
+
     field = schema.SchemaField("ignored_name", bq_type, mode="REPEATED", fields=fields)
     actual = module_under_test.bq_to_arrow_data_type(field)
-    expected_value_type = pyarrow.struct(
-        (
-            pyarrow.field("field01", pyarrow.string()),
-            pyarrow.field("field02", pyarrow.binary()),
-            pyarrow.field("field03", pyarrow.int64()),
-            pyarrow.field("field04", pyarrow.int64()),
-            pyarrow.field("field05", pyarrow.float64()),
-            pyarrow.field("field06", pyarrow.float64()),
-            pyarrow.field("field07", module_under_test.pyarrow_numeric()),
-            pyarrow.field("field08", pyarrow.bool_()),
-            pyarrow.field("field09", pyarrow.bool_()),
-            pyarrow.field("field10", module_under_test.pyarrow_timestamp()),
-            pyarrow.field("field11", pyarrow.date32()),
-            pyarrow.field("field12", module_under_test.pyarrow_time()),
-            pyarrow.field("field13", module_under_test.pyarrow_datetime()),
-            pyarrow.field("field14", pyarrow.string()),
-        )
+
+    expected = (
+        pyarrow.field("field01", pyarrow.string()),
+        pyarrow.field("field02", pyarrow.binary()),
+        pyarrow.field("field03", pyarrow.int64()),
+        pyarrow.field("field04", pyarrow.int64()),
+        pyarrow.field("field05", pyarrow.float64()),
+        pyarrow.field("field06", pyarrow.float64()),
+        pyarrow.field("field07", module_under_test.pyarrow_numeric()),
+        pyarrow.field("field09", pyarrow.bool_()),
+        pyarrow.field("field10", pyarrow.bool_()),
+        pyarrow.field("field11", module_under_test.pyarrow_timestamp()),
+        pyarrow.field("field12", pyarrow.date32()),
+        pyarrow.field("field13", module_under_test.pyarrow_time()),
+        pyarrow.field("field14", module_under_test.pyarrow_datetime()),
+        pyarrow.field("field15", pyarrow.string()),
     )
+    if _BIGNUMERIC_SUPPORT:
+        expected += (pyarrow.field("field08", module_under_test.pyarrow_bignumeric()),)
+    expected_value_type = pyarrow.struct(expected)
+
     assert pyarrow.types.is_list(actual)
     assert pyarrow.types.is_struct(actual.value_type)
     assert actual.value_type.num_fields == len(fields)
@@ -385,6 +423,16 @@ def test_bq_to_arrow_data_type_w_struct_unknown_subfield(module_under_test):
                 decimal.Decimal("999.123456789"),
             ],
         ),
+        pytest.param(
+            "BIGNUMERIC",
+            [
+                decimal.Decimal("-{d38}.{d38}".format(d38="9" * 38)),
+                None,
+                decimal.Decimal("{d38}.{d38}".format(d38="9" * 38)),
+                decimal.Decimal("3.141592653589793238462643383279"),
+            ],
+            marks=skip_if_no_bignumeric,
+        ),
         ("BOOLEAN", [True, None, False, None]),
         ("BOOL", [False, None, True, None]),
         (
@@ -841,41 +889,45 @@ def test_dataframe_to_arrow_with_required_fields(module_under_test):
         schema.SchemaField("field05", "FLOAT", mode="REQUIRED"),
         schema.SchemaField("field06", "FLOAT64", mode="REQUIRED"),
         schema.SchemaField("field07", "NUMERIC", mode="REQUIRED"),
-        schema.SchemaField("field08", "BOOLEAN", mode="REQUIRED"),
-        schema.SchemaField("field09", "BOOL", mode="REQUIRED"),
-        schema.SchemaField("field10", "TIMESTAMP", mode="REQUIRED"),
-        schema.SchemaField("field11", "DATE", mode="REQUIRED"),
-        schema.SchemaField("field12", "TIME", mode="REQUIRED"),
-        schema.SchemaField("field13", "DATETIME", mode="REQUIRED"),
-        schema.SchemaField("field14", "GEOGRAPHY", mode="REQUIRED"),
-    )
-    dataframe = pandas.DataFrame(
-        {
-            "field01": ["hello", "world"],
-            "field02": [b"abd", b"efg"],
-            "field03": [1, 2],
-            "field04": [3, 4],
-            "field05": [1.25, 9.75],
-            "field06": [-1.75, -3.5],
-            "field07": [decimal.Decimal("1.2345"), decimal.Decimal("6.7891")],
-            "field08": [True, False],
-            "field09": [False, True],
-            "field10": [
-                datetime.datetime(1970, 1, 1, 0, 0, 0, tzinfo=pytz.utc),
-                datetime.datetime(2012, 12, 21, 9, 7, 42, tzinfo=pytz.utc),
-            ],
-            "field11": [datetime.date(9999, 12, 31), datetime.date(1970, 1, 1)],
-            "field12": [datetime.time(23, 59, 59, 999999), datetime.time(12, 0, 0)],
-            "field13": [
-                datetime.datetime(1970, 1, 1, 0, 0, 0),
-                datetime.datetime(2012, 12, 21, 9, 7, 42),
-            ],
-            "field14": [
-                "POINT(30 10)",
-                "POLYGON ((30 10, 40 40, 20 40, 10 20, 30 10))",
-            ],
-        }
+        schema.SchemaField("field09", "BOOLEAN", mode="REQUIRED"),
+        schema.SchemaField("field10", "BOOL", mode="REQUIRED"),
+        schema.SchemaField("field11", "TIMESTAMP", mode="REQUIRED"),
+        schema.SchemaField("field12", "DATE", mode="REQUIRED"),
+        schema.SchemaField("field13", "TIME", mode="REQUIRED"),
+        schema.SchemaField("field14", "DATETIME", mode="REQUIRED"),
+        schema.SchemaField("field15", "GEOGRAPHY", mode="REQUIRED"),
     )
+    if _BIGNUMERIC_SUPPORT:
+        bq_schema += (schema.SchemaField("field08", "BIGNUMERIC", mode="REQUIRED"),)
+
+    data = {
+        "field01": ["hello", "world"],
+        "field02": [b"abd", b"efg"],
+        "field03": [1, 2],
+        "field04": [3, 4],
+        "field05": [1.25, 9.75],
+        "field06": [-1.75, -3.5],
+        "field07": [decimal.Decimal("1.2345"), decimal.Decimal("6.7891")],
+        "field09": [True, False],
+        "field10": [False, True],
+        "field11": [
+            datetime.datetime(1970, 1, 1, 0, 0, 0, tzinfo=pytz.utc),
+            datetime.datetime(2012, 12, 21, 9, 7, 42, tzinfo=pytz.utc),
+        ],
+        "field12": [datetime.date(9999, 12, 31), datetime.date(1970, 1, 1)],
+        "field13": [datetime.time(23, 59, 59, 999999), datetime.time(12, 0, 0)],
+        "field14": [
+            datetime.datetime(1970, 1, 1, 0, 0, 0),
+            datetime.datetime(2012, 12, 21, 9, 7, 42),
+        ],
+        "field15": ["POINT(30 10)", "POLYGON ((30 10, 40 40, 20 40, 10 20, 30 10))"],
+    }
+    if _BIGNUMERIC_SUPPORT:
+        data["field08"] = [
+            decimal.Decimal("-{d38}.{d38}".format(d38="9" * 38)),
+            decimal.Decimal("{d38}.{d38}".format(d38="9" * 38)),
+        ]
+    dataframe = pandas.DataFrame(data)
 
     arrow_table = module_under_test.dataframe_to_arrow(dataframe, bq_schema)
     arrow_schema = arrow_table.schema
@@ -1089,6 +1141,7 @@ def test_augment_schema_type_detection_succeeds(module_under_test):
                 "bytes_field": b"some bytes",
                 "string_field": u"some characters",
                 "numeric_field": decimal.Decimal("123.456"),
+                "bignumeric_field": decimal.Decimal("{d38}.{d38}".format(d38="9" * 38)),
             }
         ]
     )
@@ -1109,6 +1162,10 @@ def test_augment_schema_type_detection_succeeds(module_under_test):
         schema.SchemaField("string_field", field_type=None, mode="NULLABLE"),
         schema.SchemaField("numeric_field", field_type=None, mode="NULLABLE"),
     )
+    if _BIGNUMERIC_SUPPORT:
+        current_schema += (
+            schema.SchemaField("bignumeric_field", field_type=None, mode="NULLABLE"),
+        )
 
     with warnings.catch_warnings(record=True) as warned:
         augmented_schema = module_under_test.augment_schema(dataframe, current_schema)
@@ -1131,6 +1188,13 @@ def test_augment_schema_type_detection_succeeds(module_under_test):
         schema.SchemaField("string_field", field_type="STRING", mode="NULLABLE"),
         schema.SchemaField("numeric_field", field_type="NUMERIC", mode="NULLABLE"),
     )
+    if _BIGNUMERIC_SUPPORT:
+        expected_schema += (
+            schema.SchemaField(
+                "bignumeric_field", field_type="BIGNUMERIC", mode="NULLABLE"
+            ),
+        )
+
     by_name = operator.attrgetter("name")
     assert sorted(augmented_schema, key=by_name) == sorted(expected_schema, key=by_name)
 
